@@ -3,16 +3,17 @@ from __future__ import unicode_literals
 import time
 import re
 
-from netmiko.base_connection import BaseSSHConnection
+from netmiko.base_connection import BaseConnection
 
 
-class F5LtmSSH(BaseSSHConnection):
+class F5LtmSSH(BaseConnection):
 
     def session_preparation(self):
         """Prepare the session after the connection has been established."""
+        delay_factor = self.select_delay_factor(delay_factor=0)
         self.set_base_prompt()
         self.disable_paging(command="\nset length 0\n")
-        time.sleep(1)
+        time.sleep(1 * delay_factor)
         self.tmsh_mode()
         self.set_base_prompt()
 
@@ -20,7 +21,7 @@ class F5LtmSSH(BaseSSHConnection):
         """tmsh command is equivalent to config command on F5."""
         delay_factor = self.select_delay_factor(delay_factor)
         self.clear_buffer()
-        self.remote_conn.sendall("\ntmsh\n")
+        self.write_channel("\ntmsh\n")
         time.sleep(1 * delay_factor)
         self.clear_buffer()
         return None
